@@ -11,7 +11,7 @@
 #include "proc_mem.h"
 #endif
 
-#define VERSION "2.0.4"
+#define VERSION "2.0.5"
 
 //#define DEBUGPRINT 1
 
@@ -90,7 +90,7 @@ the following options are available:\n\
                    these are not kept unless there is strong evidence for them\n\
   -l <label>       name prefix for output transcripts (default: MSTRG)\n\
 "
-/* 
+/*
  -C output a file with reference transcripts that are covered by reads\n\
  -U unitigs are treated as reads and not as guides \n\ \\ not used now
  -d disable adaptive read coverage mode (default: yes)\n\
@@ -167,6 +167,8 @@ bool isunitig=true;
 GStr label("STRG");
 GStr ballgown_dir;
 
+GFastaDb* gfasta=NULL;
+
 GStr guidegff;
 
 bool debugMode=false;
@@ -262,7 +264,7 @@ int main(int argc, char* argv[]) {
 
  // == Process arguments.
  GArgs args(argc, argv,
-   "debug;help;version;conservative;keeptmp;bam;fr;rf;merge;exclude=zSEihvteuLx:n:j:s:D:G:C:l:m:o:a:j:c:f:p:g:P:M:Bb:A:F:T:");
+   "debug;help;version;conservative;keeptmp;rseq=;bam;fr;rf;merge;exclude=zEihvteuLx:n:j:s:D:G:C:S:l:m:o:a:j:c:f:p:g:P:M:Bb:A:F:T:");
  args.printError(USAGE, true);
 
  processOptions(args);
@@ -535,6 +537,13 @@ if (tstackSize<DEF_TSTACK_SIZE) defStackSize=DEF_TSTACK_SIZE;
 		 if (bundle->readlist.Count()>0) { // process reads in previous bundle
 			// (readthr, junctionthr, mintranscriptlen are globals)
 			bundle->getReady(currentstart, currentend);
+			if (gfasta!=NULL) { //genomic sequence data requested
+				GFaSeqGet* faseq=gfasta->fetch(bundle->refseq.chars());
+				if (faseq==NULL) {
+					GError("Error: could not retrieve sequence data for %s!\n", bundle->refseq.chars());
+				}
+				bundle->gseq=faseq->copyRange(bundle->start, bundle->end, false, true);
+			}
 #ifndef NOTHREADS
 			//push this in the bundle queue where it'll be picked up by the threads
 			DBGPRINT2("##> Locking queueMutex to push loaded bundle into the queue (bundle.start=%d)\n", bundle->start);
@@ -716,6 +725,8 @@ if (tstackSize<DEF_TSTACK_SIZE) defStackSize=DEF_TSTACK_SIZE;
 	    		"Please make sure the -G annotation file uses the same naming convention for the genome sequences.\n");
  }
 
+ delete gfasta;
+
 #ifndef NOTHREADS
  for (int t=0;t<num_cpus;t++)
 	 threads[t].join();
@@ -925,6 +936,19 @@ void processOptions(GArgs& args) {
 	 }
 	 else if(mergeMode) mintranscriptlen=50;
 
+	 /*
+	 if (args.getOpt('S')) {
+		 // sensitivitylevel=2; no longer supported from version 1.0.3
+		 sensitivitylevel=1;
+	 }
+	*/
+
+	 s=args.getOpt("rseq");
+	 if (s.is_empty())
+		 s=args.getOpt('S');
+	 if (!s.is_empty()) {
+		 gfasta=new GFastaDb(s.chars());
+	 }
 
      s=args.getOpt('x');
      if (!s.is_empty()) {
@@ -1018,13 +1042,6 @@ void processOptions(GArgs& args) {
 
 	 tmpfname=args.getOpt('o');
 
-	 /*
-	 if (args.getOpt('S')) {
-		 // sensitivitylevel=2; no longer supported from version 1.0.3
-		 sensitivitylevel=1;
-	 }
-	*/
-
 	 // coverage saturation no longer used after version 1.0.4; left here for compatibility with previous versions
 	 s=args.getOpt('s');
 	 if (!s.is_empty()) {
